@@ -17,6 +17,11 @@ zoomInPlot<-function(x,y=NULL,xlim=NULL,ylim=NULL,rxlim=xlim,rylim=ylim,
   yext<-diff(ylim)*0.04
   ryext<-diff(rylim)*0.04
  }
+ if(is.na(rxlim[1])) {
+  newbox<-locator(2)
+  rxlim<-sort(newbox$x)
+  rylim<-sort(newbox$y)
+ }
  rect(rxlim[1]-rxext,rylim[1]-ryext,rxlim[2]+rxext,rylim[2]+ryext)
  xylim<-par("usr")
  xypin<-par("pin")
@@ -41,6 +46,7 @@ zoomInPlot<-function(x,y=NULL,xlim=NULL,ylim=NULL,rxlim=xlim,rylim=ylim,
  if(is.na(xend)) xend<-xylim[1]-diff(xylim[1:2])*xymai[2]/(2*xypin[1])
  xprop0<-(xylim[1]-xend)/(xylim[1]-x0)
  xprop1<-(xylim[2]-xend)/(xylim[2]-x1)
+ par(xpd=NA)
  segments(c(x0,x0,x1,x1),c(y01,y02,y01,y02),
   c(xend,xend,xend,xend),
   c(xylim[4]-(xylim[4]-y01)*xprop0,xylim[3]+(y02-xylim[3])*xprop0,
